# Generated by roxygen2: do not edit by hand

S3method(print,cer_tbl)
export(cer_accu_aggregate)
export(cer_accu_contracts)
export(cer_accu_issuances)
export(cer_accu_methods)
export(cer_accu_projects)
export(cer_accu_relinquishments)
export(cer_cache_info)
export(cer_cite)
export(cer_clear_cache)
export(cer_deposit_zenodo)
export(cer_international_comparator)
export(cer_legislative_instrument)
export(cer_lgc_power_stations)
export(cer_manifest)
export(cer_manifest_clear)
export(cer_manifest_write)
export(cer_method_determination)
export(cer_method_integrity)
export(cer_nger_climate_active)
export(cer_nger_corporate)
export(cer_nger_electricity)
export(cer_nger_scope)
export(cer_qcmr)
export(cer_qcmr_reference)
export(cer_reconcile)
export(cer_safeguard_baseline_trajectory)
export(cer_safeguard_facilities)
export(cer_safeguard_industry_baselines)
export(cer_safeguard_teba_facilities)
export(cer_sha256)
export(cer_snapshot)
export(cer_sres_installations)
export(cer_to_carbondata)
