% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cache.R
\name{cer_clear_cache}
\alias{cer_clear_cache}
\title{Clear the cer cache}
\usage{
cer_clear_cache()
}
\value{
Invisibly returns \code{NULL}.
}
\description{
Deletes all locally cached files. The next call to any data
function will re-download from the Clean Energy Regulator.
}
\examples{
\donttest{
op <- options(cer.cache_dir = tempdir())
cer_clear_cache()
options(op)
}
}
\seealso{
Other configuration: 
\code{\link{cer_cache_info}()}
}
\concept{configuration}
