% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/safeguard.R
\name{cer_nger_corporate}
\alias{cer_nger_corporate}
\title{NGER corporate emissions and energy data}
\source{
Clean Energy Regulator, NGER reporting data and registers:
\url{https://cer.gov.au/markets/reports-and-data/nger-reporting-data-and-registers}.
Licensed under CC BY 4.0.
}
\usage{
cer_nger_corporate(year = 2025)
}
\arguments{
\item{year}{Integer. Reporting year ending 30 June.}
}
\value{
A \code{cer_tbl} with one row per reporting corporation.
}
\description{
Controlling-corporation-level Scope 1 and Scope 2 emissions and
energy use from the National Greenhouse and Energy Reporting
('NGER') scheme.
}
\details{
Published annually by the CER on 28 February. Facility-level
Scope 1 and 2 data is only published for the electricity
sector; non-electricity sectors report at this
controlling-corporation level only.
}
\examples{
\donttest{
op <- options(cer.cache_dir = tempdir())
try({
  x <- cer_nger_corporate(year = 2025)
  head(x)
})
options(op)
}
}
\references{
Commonwealth of Australia. \emph{National Greenhouse and Energy
Reporting Act 2007}; \emph{National Greenhouse and Energy
Reporting (Measurement) Determination 2008} (as amended
annually).

Greenhouse Gas Protocol (2004). \emph{A Corporate Accounting
and Reporting Standard (Revised Edition)}. World Resources
Institute.

Department of Climate Change, Energy, the Environment and Water
(annual). \emph{NGER Technical Guidelines}. Methodology for
Scope 1 and Scope 2 calculations.
}
\seealso{
Other nger: 
\code{\link{cer_nger_climate_active}()},
\code{\link{cer_nger_electricity}()},
\code{\link{cer_nger_scope}()}
}
\concept{nger}
