% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accu.R
\name{cer_accu_contracts}
\alias{cer_accu_contracts}
\title{ACCU Carbon Abatement Contract register}
\source{
Clean Energy Regulator Carbon Abatement Contract register
(CC BY 4.0).
}
\usage{
cer_accu_contracts(auction = NULL)
}
\arguments{
\item{auction}{Optional character vector of auction identifiers
(e.g. \code{"ERF Auction 18"}).}
}
\value{
A \code{cer_tbl} with one row per contract.
}
\description{
Government purchase contracts under Emissions Reduction Fund
auctions administered by the CER.
}
\examples{
\donttest{
op <- options(cer.cache_dir = tempdir())
cer_accu_contracts()
options(op)
}
}
\seealso{
Other accu: 
\code{\link{cer_accu_aggregate}()},
\code{\link{cer_accu_issuances}()},
\code{\link{cer_accu_methods}()},
\code{\link{cer_accu_projects}()},
\code{\link{cer_accu_relinquishments}()},
\code{\link{cer_method_determination}()},
\code{\link{cer_method_integrity}()}
}
\concept{accu}
