% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/interop.R
\name{cer_international_comparator}
\alias{cer_international_comparator}
\title{Bundled international carbon market comparator}
\usage{
cer_international_comparator()
}
\value{
A \code{cer_tbl} of indicative comparator data.
}
\description{
Returns headline price/volume figures for comparison between
ACCU (Australia) and major international markets: EU ETS, New
Zealand ETS, California-Quebec (WCI), Verra VCUs, and Gold
Standard. Values are indicative snapshots. For live data use
the companion \code{carbondata} package.
}
\examples{
cer_international_comparator()
}
\references{
International Carbon Action Partnership (annual). \emph{Emissions
Trading Worldwide: Status Report}. \url{https://icapcarbonaction.com/en}

World Bank (annual). \emph{State and Trends of Carbon Pricing}.
}
\seealso{
Other interop: 
\code{\link{cer_to_carbondata}()}
}
\concept{interop}
