% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/safeguard.R
\name{cer_nger_electricity}
\alias{cer_nger_electricity}
\title{NGER electricity sector facility emissions}
\source{
Clean Energy Regulator, National Greenhouse and Energy
Register:
\url{https://cer.gov.au/markets/reports-and-data/nger-reporting-data-and-registers}.
Licensed under CC BY 4.0.
}
\usage{
cer_nger_electricity(year = 2025, facility = NULL)
}
\arguments{
\item{year}{Integer. Reporting year ending 30 June.}

\item{facility}{Optional character vector of facility name
substrings (case-insensitive).}
}
\value{
A \code{cer_tbl} with one row per generator facility.
}
\description{
Facility-level Scope 1 emissions and generated electricity for
facilities in the electricity generation sector that met the
NGER reporting threshold.
}
\examples{
\donttest{
op <- options(cer.cache_dir = tempdir())
try({
  e <- cer_nger_electricity(year = 2025, facility = "Bayswater")
  head(e)
})
options(op)
}
}
\seealso{
Other nger: 
\code{\link{cer_nger_climate_active}()},
\code{\link{cer_nger_corporate}()},
\code{\link{cer_nger_scope}()}
}
\concept{nger}
