% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/manifest.R
\name{cer_manifest_write}
\alias{cer_manifest_write}
\title{Write the session manifest to a file}
\usage{
cer_manifest_write(path, format = c("auto", "csv", "yaml", "json"))
}
\arguments{
\item{path}{Output file path. Extension determines format when
\code{format = "auto"}.}

\item{format}{One of \code{"auto"}, \code{"csv"}, \code{"yaml"}, \code{"json"}.}
}
\value{
Invisibly, the absolute path written.
}
\description{
Write the session manifest to a file
}
\examples{
\donttest{
p <- tempfile(fileext = ".csv")
cer_manifest_clear()
cer_manifest_write(p)
}
}
\seealso{
Other reproducibility: 
\code{\link{cer_cite}()},
\code{\link{cer_deposit_zenodo}()},
\code{\link{cer_legislative_instrument}()},
\code{\link{cer_manifest}()},
\code{\link{cer_manifest_clear}()},
\code{\link{cer_sha256}()},
\code{\link{cer_snapshot}()}
}
\concept{reproducibility}
