% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lret_sres.R
\name{cer_sres_installations}
\alias{cer_sres_installations}
\title{SRES small-scale installations by postcode}
\source{
Clean Energy Regulator, Small-scale installation
postcode data:
\url{https://cer.gov.au/markets/reports-and-data/small-scale-installation-postcode-data}.
Licensed under CC BY 4.0.
}
\usage{
cer_sres_installations(
  technology = c("solar_pv", "swh", "heat_pump", "battery"),
  postcode = NULL,
  measure = c("installations", "capacity")
)
}
\arguments{
\item{technology}{Character. One of \code{"solar_pv"} (default), \code{"swh"}
(solar water heater), \code{"heat_pump"}, or \code{"battery"}.}

\item{postcode}{Optional character vector of 4-digit Australian
postcodes to filter on.}

\item{measure}{Character. \code{"installations"} (default, counts) or
\code{"capacity"} (total kW installed).}
}
\value{
A \code{cer_tbl}. For \code{measure = "installations"} columns
include postcode and per-month install counts. For
\code{measure = "capacity"}, per-month kW capacity.
}
\description{
Monthly Small-scale Renewable Energy Scheme ('SRES') installation
counts or capacity by postcode. Covers rooftop solar PV, solar
water heaters, air-source heat pumps, and small batteries.
}
\examples{
\donttest{
op <- options(cer.cache_dir = tempdir())
inst <- cer_sres_installations(postcode = c("2000", "3000"))
head(inst)
options(op)
}
}
\references{
Commonwealth of Australia. \emph{Renewable Energy (Electricity)
Act 2000}, Small-scale Renewable Energy Scheme provisions.

Australian Energy Market Operator (2024). \emph{Distributed PV
Forecasting Methodology}. AEMO uses SRES installation data
as input to ISP and ESOO forecasts.

Best, R., Burke, P.J. and Nishitateno, S. (2019).
"Understanding the determinants of rooftop solar
installation: evidence from household surveys in Australia."
\emph{Australian Journal of Agricultural and Resource
Economics}, 63(4), 922-939.
\doi{10.1111/1467-8489.12319}
}
\concept{sres}
