% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reconcile.R
\name{cer_qcmr_reference}
\alias{cer_qcmr_reference}
\title{QCMR headline reference totals}
\usage{
cer_qcmr_reference(quarter = NULL, measure = NULL)
}
\arguments{
\item{quarter}{Optional character filter (e.g. \code{"2024-Q4"}).}

\item{measure}{Optional character filter (e.g.
\code{"accu_cumulative_issuances"}).}
}
\value{
A \code{cer_tbl} of reference totals.
}
\description{
Bundled quarterly Clean Energy Regulator QCMR headline figures
for cross-validation of live-fetched aggregates.
}
\examples{
cer_qcmr_reference()
cer_qcmr_reference(quarter = "2024-Q4")
}
\seealso{
Other reconciliation: 
\code{\link{cer_reconcile}()}
}
\concept{reconciliation}
